==> cxf-testutils-2.0.6.11-fuse-sources.jar: org/apache/type_test/doc/TestDerivedChoiceBaseStruct.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.DerivedChoiceBaseStruct;


/**
 * <p>Java class for testDerivedChoiceBaseStruct element declaration.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;element name="testDerivedChoiceBaseStruct">
 *   &lt;complexType>
 *     &lt;complexContent>
 *       &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *         &lt;sequence>
 *           &lt;element name="x" type="{http://apache.org/type_test/types1}DerivedChoiceBaseStruct"/>
 *           &lt;element name="y" type="{http://apache.org/type_test/types1}DerivedChoiceBaseStruct"/>
 *         &lt;/sequence>
 *       &lt;/restriction>
 *     &lt;/complexContent>
 *   &lt;/complexType>
 * &lt;/element>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testDerivedChoiceBaseStruct")
public class TestDerivedChoiceBaseStruct {

    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected DerivedChoiceBaseStruct x;
    @XmlElement(namespace = "http://apache.org/type_test/doc", required = true)
    protected DerivedChoiceBaseStruct y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link DerivedChoiceBaseStruct }
     *     
     */
    public DerivedChoiceBaseStruct getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link DerivedChoiceBaseStruct }
     *     
     */
    public void setX(DerivedChoiceBaseStruct value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link DerivedChoiceBaseStruct }
     *     
     */
    public DerivedChoiceBaseStruct getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link DerivedChoiceBaseStruct }
     *     
     */
    public void setY(DerivedChoiceBaseStruct value) {
        this.y = value;
    }

}

==> cxf-testutils-2.1.3.13-fuse-sources.jar: org/apache/type_test/doc/TestDerivedChoiceBaseStruct.java <==

package org.apache.type_test.doc;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import org.apache.type_test.types1.DerivedChoiceBaseStruct;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="x" type="{http://apache.org/type_test/types1}DerivedChoiceBaseStruct"/>
 *         &lt;element name="y" type="{http://apache.org/type_test/types1}DerivedChoiceBaseStruct"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "x",
    "y"
})
@XmlRootElement(name = "testDerivedChoiceBaseStruct")
public class TestDerivedChoiceBaseStruct {

    @XmlElement(required = true)
    protected DerivedChoiceBaseStruct x;
    @XmlElement(required = true)
    protected DerivedChoiceBaseStruct y;

    /**
     * Gets the value of the x property.
     * 
     * @return
     *     possible object is
     *     {@link DerivedChoiceBaseStruct }
     *     
     */
    public DerivedChoiceBaseStruct getX() {
        return x;
    }

    /**
     * Sets the value of the x property.
     * 
     * @param value
     *     allowed object is
     *     {@link DerivedChoiceBaseStruct }
     *     
     */
    public void setX(DerivedChoiceBaseStruct value) {
        this.x = value;
    }

    /**
     * Gets the value of the y property.
     * 
     * @return
     *     possible object is
     *     {@link DerivedChoiceBaseStruct }
     *     
     */
    public DerivedChoiceBaseStruct getY() {
        return y;
    }

    /**
     * Sets the value of the y property.
     * 
     * @param value
     *     allowed object is
     *     {@link DerivedChoiceBaseStruct }
     *     
     */
    public void setY(DerivedChoiceBaseStruct value) {
        this.y = value;
    }

}
